/**
 * Copyright (c) 2025 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "overworld.h"
#include "chunk.h"
#include "display/render.h"
#include "assert/assert.h"

uint32_t OVERWORLD_CAMERA_X;
uint32_t OVERWORLD_CAMERA_Y;
overworldcameratype_t OVERWORLD_CAMERA_TYPE;

void overworldInit(void) {
  chunkMapInit();
  OVERWORLD_CAMERA_X = 0;
  OVERWORLD_CAMERA_Y = 0;
  OVERWORLD_CAMERA_TYPE = OVERWORLD_CAMERA_TYPE_CENTERED_POSITION;
}

void overworldUpdate() {
  assertTrue(
    OVERWORLD_CAMERA_X < OVERWORLD_CAMERA_LIMIT_X,
    "Camera position limit (just because I haven't tested properly)"
  );
  assertTrue(
    OVERWORLD_CAMERA_Y < OVERWORLD_CAMERA_LIMIT_Y,
    "Camera position limit (just because I haven't tested properly)"
  );

  uint16_t x, y;
  if(OVERWORLD_CAMERA_X < RENDER_WIDTH / 2) {
    x = 0;
  } else {
    x = (OVERWORLD_CAMERA_X - (RENDER_WIDTH / 2)) / (CHUNK_WIDTH*TILE_WIDTH);
  }

  if(OVERWORLD_CAMERA_Y < RENDER_HEIGHT / 2) {
    y = 0;
  } else {
    y = (OVERWORLD_CAMERA_Y -(RENDER_HEIGHT / 2)) / (CHUNK_HEIGHT*TILE_HEIGHT);
  }

  chunkMapSetPosition(x, y);
}