/**
 * Copyright (c) 2025 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "drawoverworld.h"
#include "world/chunk.h"
#include "world/overworld.h"
#include "display/render.h"

Camera2D DRAW_OVERWORLD_CAMERA = { 0 };

void drawOverworldInit(void) {
  DRAW_OVERWORLD_CAMERA = (Camera2D){
    .offset = { 0, 0 },
    .target = { 0, 0 },
    .rotation = 0.0f,
    .zoom = 1.0f
  };
}

void drawOverworldDraw(void) {
  if(OVERWORLD_CAMERA_X < RENDER_WIDTH / 2) {
    DRAW_OVERWORLD_CAMERA.target.x = 0;
  } else {
    DRAW_OVERWORLD_CAMERA.target.x = (OVERWORLD_CAMERA_X - RENDER_WIDTH) / 2;
  }

  if(OVERWORLD_CAMERA_Y < RENDER_HEIGHT / 2) {
    DRAW_OVERWORLD_CAMERA.target.y = 0;
  } else {
    DRAW_OVERWORLD_CAMERA.target.y = (OVERWORLD_CAMERA_Y - RENDER_HEIGHT) / 2;
  }
  
  BeginMode2D(DRAW_OVERWORLD_CAMERA);

  chunk_t *chunk = CHUNK_MAP.chunks;
  do {
    DrawRectangle(
      ((int32_t)chunk->x) * CHUNK_WIDTH * TILE_WIDTH,
      ((int32_t)chunk->y) * CHUNK_HEIGHT * TILE_HEIGHT,
      CHUNK_WIDTH * TILE_WIDTH,
      CHUNK_HEIGHT * TILE_HEIGHT,
      (chunk->tiles[0] == 0) ? RED : GREEN
    );
    chunk++;
  } while(chunk < CHUNK_MAP.chunks + CHUNK_MAP_COUNT);

  EndMode2D();
}